#!/usr/bin/env python2.7
# Copyright 2013 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Helper to compare the names in an archive with the filesystem.

More specifically, the names of - and contained within - one or more
directories. Typically these would be top-level Python package
directories, and the archive would be a source distribution of the
aforementioned archive.

"""

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

str = None

__metaclass__ = type

import argparse
from fnmatch import fnmatchcase
from itertools import (
    chain,
    imap,
    )
import os
from os.path import join
import tarfile


ignore = [
    "*.egg-info",
    "*.egg-info/*",
    "*.py[co]",
    "MANIFEST.in",
    "PKG-INFO",
    "README.*",
    "setup.cfg",
    "setup.py",
]


# See http://docs.python.org/release/2.7/library/argparse.html.
argument_parser = argparse.ArgumentParser(description=__doc__)
argument_parser.add_argument(
    "archive", type=bytes, help="The archive to compare.")
argument_parser.add_argument(
    "directories", metavar="directory", nargs="+", type=bytes,
    help="Directories to compare.")
argument_parser.add_argument(
    "--ignore", action="append", type=bytes, default=ignore,
    help="Full-path patterns to ignore (default: %s)." % ", ".join(ignore))


def walk_tarball(filename):
    for name in tarfile.open(args.archive, "r").getnames():
        parts = name.split(b"/")
        if len(parts) > 1:
            yield b"/".join(parts[1:])


def walk_directory(directory):
    yield directory
    for root, dirnames, filenames in os.walk(directory):
        for dirname in dirnames:
            yield join(root, dirname)
        for filename in filenames:
            yield join(root, filename)


def filter_matching_paths(paths, ignore):
    for path in paths:
        for pattern in ignore:
            if fnmatchcase(path, pattern):
                break
        else:
            yield path


if __name__ == "__main__":
    args = argument_parser.parse_args()
    names_from_dist = walk_tarball(args.archive)
    names_from_dist = filter_matching_paths(names_from_dist, args.ignore)
    names_from_dist = set(names_from_dist)
    names_from_fs = imap(walk_directory, args.directories)
    names_from_fs = chain.from_iterable(names_from_fs)
    names_from_fs = filter_matching_paths(names_from_fs, args.ignore)
    names_from_fs = set(names_from_fs)
    for name in sorted(names_from_dist - names_from_fs):
        print("+", name)
    for name in sorted(names_from_fs - names_from_dist):
        print("-", name)
