# Copyright 2012-2014 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Django DEVELOPMENT settings for maas project."""

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

str = None

__metaclass__ = type

import logging
from os.path import (
    abspath,
    dirname,
    join,
    )

from maas import (
    import_local_settings,
    import_settings,
    settings,
    )
from metadataserver.address import guess_server_address
from pkg_resources import (
    Requirement,
    resource_filename,
    )
import provisioningserver.config
from provisioningserver.utils import compose_URL_on_IP
from psycopg2.extensions import ISOLATION_LEVEL_SERIALIZABLE

# We expect the following settings to be overridden. They are mentioned here
# to silence lint warnings.
INSTALLED_APPS = None

# Extend base settings.
import_settings(settings)

# In development, django can be accessed directly on port 5240.
DEFAULT_MAAS_URL = compose_URL_on_IP("http://:5240/", guess_server_address())

# Don't connect to the DNS server in tests, this will be enabled on a case per
# case basis.
DNS_CONNECT = False

# Don't setup DHCP servers in tests, this will be enabled on a case per case
# basis.
DHCP_CONNECT = False

# Invalid strings should be visible.
TEMPLATE_STRING_IF_INVALID = '#### INVALID STRING ####'

DEBUG = True
TEMPLATE_DEBUG = DEBUG
YUI_DEBUG = DEBUG
STATIC_LOCAL_SERVE = True

RABBITMQ_PUBLISH = False

# Silent South during tests.
logging.getLogger('south').setLevel(logging.WARNING)

DATABASES = {
    'default': {
        # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' etc.
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': 'maas',
        # For PostgreSQL, a "hostname" starting with a slash indicates a
        # Unix socket directory.
        'HOST': abspath('db'),
        'OPTIONS': {
            'isolation_level': ISOLATION_LEVEL_SERIALIZABLE,
        },
    },
}

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = resource_filename(
    Requirement.parse("maas-develop"), "media/development")

INSTALLED_APPS += (
    'django.contrib.admin',
    'maastesting',
)

INTERNAL_IPS = ('127.0.0.1',)

DEBUG_TOOLBAR_CONFIG = {
    'INTERCEPT_REDIRECTS': False,
    }

# Make all nodes' metadata visible.  This is not safe; do not enable it
# on a production MAAS.
ALLOW_UNSAFE_METADATA_ACCESS = True

# Use in-branch preseed templates.
PRESEED_TEMPLATE_LOCATIONS = resource_filename(
    Requirement.parse("maas-region"), "etc/maas/preseeds")

# Override the default provisioning config filename.
provisioningserver.config.Config.DEFAULT_FILENAME = resource_filename(
    Requirement.parse("maas-region"), "etc/maas/pserv.yaml")

# Use the in-branch development version of maas_cluster.conf.
LOCAL_CLUSTER_CONFIG = abspath(
    join(dirname(__file__), "maas_cluster.demo.conf"))

PASSWORD_HASHERS = (
    'django.contrib.auth.hashers.MD5PasswordHasher',
)

# Allow the user to override settings in maas_local_settings.
import_local_settings()
