# Copyright 2014 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Entry-points for testing all of MAAS."""

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

str = None

__metaclass__ = type
__all__ = [
    "test_apiclient",
    "test_client",
    "test_cluster",
    "test_region",
    "test_testing",
]

from os import (
    chdir,
    environ,
    execv,
    )
import subprocess
import sys

from pkg_resources import (
    Requirement,
    resource_filename,
    )


def test(name):
    chdir(resource_filename(Requirement.parse(name), None))
    cmd = ["bin/python", "setup.py", "test"] + sys.argv[1:]
    subprocess.check_call(("make", "--quiet"))
    execv("bin/python", cmd)


def test_apiclient():
    environ.setdefault(
        "DJANGO_SETTINGS_MODULE",
        "apiclient.testing.settings")
    test("maas-apiclient")


def test_client():
    test("maas-client")


def test_cluster():
    environ.setdefault(
        "CELERY_CONFIG_MODULE",
        "provisioningserver.testing.celeryconfig")
    environ.setdefault(
        "DJANGO_SETTINGS_MODULE",
        "provisioningserver.testing.djangosettings")
    environ.setdefault(
        "MAAS_CONFIG_DIR", resource_filename(
            Requirement.parse("maas-cluster"), "etc/maas"))
    test("maas-cluster")


def test_region():
    environ.setdefault(
        "CELERY_CONFIG_MODULE",
        "maas.testing.celeryconfig")
    environ.setdefault(
        "DJANGO_SETTINGS_MODULE",
        "maas.testing.djangosettings")
    environ.setdefault(
        "MAAS_CONFIG_DIR", resource_filename(
            Requirement.parse("maas-region"), "etc/maas"))
    test("maas-region")


def test_testing():
    test("maas-testing")
