# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Testing infrastructure for MAAS."""

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

str = None

__metaclass__ = type
__all__ = [
    "bindir",
    "root",
    ]

from os import (
    getcwd,
    path,
    )
import re
from sys import executable
from warnings import filterwarnings

# The root of the source tree. Relies on having a symlink named ".root"
# in the current working directory or above. Use of root is deprecated
# now that different parts of MAAS are separately packaged (in Python
# terms).
root = getcwd()
while root != path.sep:
    rootflag = path.join(root, ".root")
    if path.islink(rootflag):
        root = path.realpath(rootflag)
        break
    elif path.isfile(rootflag):
        root = path.realpath(root)
        break
    else:
        root = path.dirname(root)
else:
    raise AssertionError(
        "Could not find branch root starting from %s" % getcwd())

# The directory containing the current interpreter.
bindir = path.abspath(path.dirname(executable))

# Construct a regular expression that matches all of MAAS's core
# packages, and their subpackages.
packages = {
    "apiclient",
    "maas",
    "maascli",
    "maasserver",
    "maastesting",
    "metadataserver",
    "provisioningserver",
}
packages_expr = r"^(?:%s)\b" % "|".join(
    re.escape(package) for package in packages)

# Enable some warnings that we ought to pay heed to.
filterwarnings('default', category=BytesWarning, module=packages_expr)
filterwarnings('default', category=DeprecationWarning, module=packages_expr)
filterwarnings('default', category=ImportWarning, module=packages_expr)
